Changes
=======

0.3 (2023-07-17)
----------------

- Add support for adding content items.
- Add support for building and cleaning site.

0.2 (2023-07-12)
----------------

- Internationalize type names in edit forms.
- Properly handle adding/deleting/reordering flow blocks.
- Add support for deleting multiple selected content items.
- Add support for time widgets.
- Add dark-light mode toggle.

0.1 (2023-07-04)
----------------

- Initial release.
